pub struct SyntheticToolResult {
pub body: ToolResultBody,
pub is_error: bool,
}Expand description
A synthetic tool result produced by a hook — setting BeforeToolApply::result
effectively “intercepts” the tool.
Fields
body: ToolResultBodyis_error: boolTrait Implementations
Sourceimpl Clone for SyntheticToolResult
impl Clone for SyntheticToolResult
Sourcefn clone(&self) -> SyntheticToolResult
fn clone(&self) -> SyntheticToolResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SyntheticToolResult
impl Debug for SyntheticToolResult
Sourceimpl PartialEq for SyntheticToolResult
impl PartialEq for SyntheticToolResult
Sourcefn eq(&self, other: &SyntheticToolResult) -> bool
fn eq(&self, other: &SyntheticToolResult) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SyntheticToolResult