pub struct ToolBatchEntry {
pub tool_name: String,
pub is_error: bool,
}Expand description
A summary entry for a batch of parallel tool results (for envelope use).
Fields
tool_name: Stringis_error: boolTrait Implementations
Sourceimpl Clone for ToolBatchEntry
impl Clone for ToolBatchEntry
Sourcefn clone(&self) -> ToolBatchEntry
fn clone(&self) -> ToolBatchEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolBatchEntry
impl Debug for ToolBatchEntry
impl Eq for ToolBatchEntry
Sourceimpl PartialEq for ToolBatchEntry
impl PartialEq for ToolBatchEntry
Sourcefn eq(&self, other: &ToolBatchEntry) -> bool
fn eq(&self, other: &ToolBatchEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ToolBatchEntry