ProviderStream

Type Alias ProviderStream 

pub type ProviderStream = Pin<Box<dyn Stream<Item = Result<ProviderChunk, ProviderError>> + Send>>;
A type-erased stream of events produced by a provider during streaming generation, enabling direct use with dyn LlmProvider.

Aliased Type

pub struct ProviderStream { /* private fields */ }