#[non_exhaustive]pub enum RecordedOutcome {
Selected {
option_id: PermissionOptionId,
allows: bool,
},
Cancelled,
}Expand description
The “user response” that the main loop writes back to the policy.
Selected::allows is filled into AskOption by the policy during
SandboxPolicy::classify; the main loop looks it up by option_id and feeds it
back, avoiding the policy having to re-parse the option id it just sent.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Selected
Cancelled
The user cancelled the turn. The policy does not update the authorization table, but may perform auditing.