#[non_exhaustive]pub enum TurnError {
TurnInProgress,
Provider(ProviderError),
Internal(BoxError),
}Expand description
Reasons why a turn fails.
Rule of thumb: only include errors that make the turn unable to continue. Internal
tool failures within a turn, single LLM retry failures, etc. belong in AgentEvent
and the historical state machine instead.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TurnInProgress
A turn is already in progress for this session.
Provider(ProviderError)
Provider error that still fails after retries are exhausted.
Internal(BoxError)
Internal invariant broken (should be a bug).