pub struct ModelSelection {
pub provider: String,
pub model: String,
}Expand description
Model selection key: a (provider vendor, model id) pair.
The same model id can be declared by multiple providers (multiple gateways with the
same model), so selection must include both the provider vendor and the model id.
provider refers to ProviderInfo::vendor.
Fields
provider: Stringmodel: StringTrait Implementations
Sourceimpl Clone for ModelSelection
impl Clone for ModelSelection
Sourcefn clone(&self) -> ModelSelection
fn clone(&self) -> ModelSelection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelSelection
impl Debug for ModelSelection
impl Eq for ModelSelection
Sourceimpl PartialEq for ModelSelection
impl PartialEq for ModelSelection
Sourcefn eq(&self, other: &ModelSelection) -> bool
fn eq(&self, other: &ModelSelection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ModelSelection