StaticToolRegistryBuilder

Struct StaticToolRegistryBuilder 

pub struct StaticToolRegistryBuilder { /* private fields */ }
A builder for StaticToolRegistry.

Implementations

Source

impl StaticToolRegistryBuilder

pub fn insert(self, tool: Arc<dyn Tool>) -> Self

Registers a tool. If a tool with the same name already exists, it is overwritten and the old entry in schemas is replaced with the new one (keeping schemas order stable for diagnostics).

pub fn build(self) -> StaticToolRegistry