#[non_exhaustive]pub enum ShellError {
NotFound(TerminalId),
Backend(BoxError),
NotPermitted(String),
}Expand description
Errors from the shell backend.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound(TerminalId)
The terminal ID refers to a non-existent or already-released terminal.
Backend(BoxError)
Backend failed to spawn a child process or communicate with the client.
NotPermitted(String)
Operation not permitted: cwd out of bounds, client denied, insufficient permissions, etc.