pub struct ShellOutput {
pub text: String,
pub truncated: bool,
pub exit_status: Option<TerminalExitStatus>,
}Expand description
A snapshot result of ShellBackend::output.
Fields
text: StringAccumulated combined stdout/stderr text up to this call. The backend guarantees valid UTF-8.
truncated: boolWhether the output was truncated by the backend due to a byte limit.
exit_status: Option<TerminalExitStatus>Set to the actual exit status when the process has exited, or None if it is
still running.