pub struct SkillTool { /* private fields */ }Expand description
The skill tool. It is registered on StaticToolRegistry and shared across sessions
of the owning AgentCore via process_tools (it is not a process-global
singleton—a single process may host multiple AgentCore instances, each with its own
skill index).
Implementations
Sourceimpl SkillTool
impl SkillTool
Sourcepub fn new(skills: Arc<BTreeMap<String, SkillEntry>>) -> Self
pub fn new(skills: Arc<BTreeMap<String, SkillEntry>>) -> Self
Constructs a skill tool. When skills is empty, callers should not register
this tool
(the schema’s name enum will be empty, so it will always fail) — see
Self::has_skills.
Sourcepub fn has_skills(skills: &BTreeMap<String, SkillEntry>) -> bool
pub fn has_skills(skills: &BTreeMap<String, SkillEntry>) -> bool
Whether any skills were discovered. The assembler uses this to decide whether to register this tool.